// java wrapper for vtkOpenGLActor object
//

package vtk;
import vtk.*;

public class vtkOpenGLActor extends vtkActor
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Render_2(vtkRenderer id0,vtkMapper id1);
  public void Render(vtkRenderer id0,vtkMapper id1)
    { Render_2(id0,id1); }

  private native long GLDepthMaskOverride_3();
  public vtkInformationIntegerKey GLDepthMaskOverride() {
    long temp = GLDepthMaskOverride_3();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkOpenGLActor() { super(); }

  public vtkOpenGLActor(long id) { super(id); }
  public native long   VTKInit();

}
